==> xl-security-24.1.0-730.1124-sources.jar: com/xebialabs/deployit/security/permission/ReadPermissionHandler.java <==
package com.xebialabs.deployit.security.permission;

import com.xebialabs.deployit.repository.SearchParameters;
import com.xebialabs.deployit.security.PermissionEnforcer;
import com.xebialabs.deployit.security.Role;
import com.xebialabs.deployit.security.RolesPermissionsPair;
import com.xebialabs.deployit.security.SecurityServiceLocator;
import com.xebialabs.deployit.security.authentication.viewas.ViewAsData;

import java.util.List;
import java.util.stream.Collectors;

import static com.xebialabs.deployit.security.Permissions.getAuthentication;

public class ReadPermissionHandler extends PermissionHandler {

    public ReadPermissionHandler() {
        super(PlatformPermissions.READ);
    }

    @Override
    public boolean hasPermission(String onConfigurationItem) {
        PermissionEnforcer permissionEnforcer = SecurityServiceLocator.getPermissionEnforcer();
        ViewAsData viewAsData = SecurityServiceLocator.getViewAsData();
        if (viewAsData != null) {
            if (viewAsData.getUser() != null) {
                return permissionEnforcer.hasPermission(viewAsData.getUser(), Permission.getReadPermissions(), onConfigurationItem);
            } else if (viewAsData.getRoles() != null) {
                return permissionEnforcer.hasPermission(viewAsData.getRoles(), Permission.getReadPermissions(), onConfigurationItem);
            }
        }
        return permissionEnforcer.hasLoggedInUserPermission(Permission.getReadPermissions(), onConfigurationItem);
    }

    private List<Role> getCurrentRoles(ViewAsData viewAsData) {
        PermissionEnforcer permissionEnforcer = SecurityServiceLocator.getPermissionEnforcer();
        if (viewAsData != null) {
            if (viewAsData.getUser() != null) {
                return permissionEnforcer.getUserRoles(viewAsData.getUser());
            } else if (viewAsData.getRoles() != null) {
                return viewAsData.getRoles();
            }
        }
        return permissionEnforcer.getUserRoles(getAuthentication());
    }

    @Override
    public RolesPermissionsPair getRolesPermissionsPair() {
        ViewAsData viewAsData = SecurityServiceLocator.getViewAsData();
        return new RolesPermissionsPair(
                getCurrentRoles(viewAsData).stream().map(Role::getId).collect(Collectors.toList()),
                Permission.getReadPermissions().stream().map(Permission::getPermissionName).collect(Collectors.toList()));
    }

    @Override
    public void applyPermission(SearchParameters parameters) {
        PermissionEnforcer permissionEnforcer = SecurityServiceLocator.getPermissionEnforcer();
        ViewAsData viewAsData = SecurityServiceLocator.getViewAsData();
        if (viewAsData != null && (viewAsData.getUser() != null || viewAsData.getRoles() != null)) {
            permissionEnforcer.applyPermission(parameters, getCurrentRoles(viewAsData), Permission.getReadPermissions());
        }
        else {
            permissionEnforcer.applyLoggedInUserPermission(parameters, Permission.getReadPermissions());
        }
    }
}

==> xl-security-2018.3.2-sources.jar: com/xebialabs/deployit/security/permission/ReadPermissionHandler.java <==
package com.xebialabs.deployit.security.permission;

import java.util.List;
import com.typesafe.config.ConfigException;

import com.xebialabs.deployit.repository.SearchParameters;
import com.xebialabs.deployit.security.authentication.viewas.ViewAsData;
import org.springframework.beans.factory.BeanCreationException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.Authentication;

import com.xebialabs.deployit.security.PermissionEnforcer;
import com.xebialabs.deployit.security.Permissions;
import com.xebialabs.deployit.security.SecurityServiceLocator;

public class ReadPermissionHandler extends PermissionHandler {

    public ReadPermissionHandler() {
        super(PlatformPermissions.READ);
    }

    @Override
    public boolean hasPermission(String onConfigurationItem) {
        PermissionEnforcer permissionEnforcer = SecurityServiceLocator.getPermissionEnforcer();
        ViewAsData viewAsData = SecurityServiceLocator.getViewAsData();
        if (viewAsData != null) {
            if (viewAsData.getUser() != null) {
                return permissionEnforcer.hasPermission(viewAsData.getUser(), Permission.getReadPermissions(), onConfigurationItem);
            } else if (viewAsData.getRoles() != null) {
                return permissionEnforcer.hasPermission(viewAsData.getRoles(), Permission.getReadPermissions(), onConfigurationItem);
            }
        }
        return permissionEnforcer.hasLoggedInUserPermission(Permission.getReadPermissions(), onConfigurationItem);
    }

    @Override
    public void applyPermission(SearchParameters parameters) {
        PermissionEnforcer permissionEnforcer = SecurityServiceLocator.getPermissionEnforcer();
        ViewAsData viewAsData = SecurityServiceLocator.getViewAsData();
        if (viewAsData != null) {
            if (viewAsData.getUser() != null) {
                permissionEnforcer.applyPermission(parameters, viewAsData.getUser(), Permission.getReadPermissions());
            } else if (viewAsData.getRoles() != null) {
                permissionEnforcer.applyPermission(parameters, viewAsData.getRoles(), Permission.getReadPermissions());
            }
        }
        permissionEnforcer.applyLoggedInUserPermission(parameters, Permission.getReadPermissions());
    }
}
